@@ -101,7 +101,7 @@
 #include <pbs_config.h>   /* the master config generated by configure */
 
 int exitstatus = 0; /* Exit Status */
-static void execute();
+static void execute(char *, char *, char *, int);
 
 
 
