@@ -81,7 +81,7 @@
  * include file for error/event logging
  */
 
-#define LOG_BUF_SIZE		4096
+#define LOG_BUF_SIZE		16384
 
 /* The following macro assist in sharing code between the Server and Mom */
 #define LOG_EVENT log_event
@@ -109,8 +109,9 @@ extern void log_record A_((int,int,char *,char *));
 extern void log_roll A_((int));
 extern long log_size A_((void));
 extern char log_buffer[LOG_BUF_SIZE];
+int log_init A_((char *,char *));
 
-extern int  chk_file_sec A_((char *,int,int,int,int));
+extern int  chk_file_sec A_((char *,int,int,int,int,char *));
 extern int  setup_env A_((char *));
 
 
