@@ -78,7 +78,7 @@
 */
 
 /*
- * @(#) $Id: qmgr_svr_readonly.h 12 2005-02-22 20:59:54Z dev $
+ * @(#) $Id: qmgr_svr_readonly.h 1809 2008-02-02 03:41:20Z garrick $
  */
 
 /*
@@ -96,4 +96,5 @@ ATTR_rescassn,
 ATTR_count,
 ATTR_status,
 ATTR_total,
-
+ATTR_netcounter,
+ATTR_pbsversion,
