@@ -79,7 +79,7 @@
 
 
 /*
- * @(#) $Id: tm.h 12 2005-02-22 20:59:54Z dev $
+ * @(#) $Id: tm.h 2324 2008-08-11 20:53:18Z josh $
  */
 
 /*
@@ -187,3 +187,13 @@ int	tm_destroy_event(tm_event_t	*event);
 
 int	tm_register(	tm_whattodo_t	*what,
 			tm_event_t	*event);
+
+/*
+ *  DJH 15 Nov 2001.
+ *  Generic "out-of-band" task adoption call for tasks parented by
+ *  another job management system.  Minor security hole?
+ *  Cannot be called with any other tm call.
+ *  26 Feb 2002. Allows id to be jobid (adoptCmd = TM_ADOPT_JOBID)
+ *  or some altid (adoptCmd = TM_ADOPT_ALTID)
+ */
+int tm_adopt(char *id, int adoptCmd, pid_t pid); 
