@@ -84,7 +84,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <pbs_ifl.h>
+#include "pbs_ifl.h"
 #include "list_link.h"
 #include "attribute.h"
 #include "pbs_error.h"
