@@ -86,7 +86,7 @@
 #endif
 #include <stdlib.h>
 #include <string.h>
-#include <pbs_ifl.h>
+#include "pbs_ifl.h"
 #include "list_link.h"
 #include "attribute.h"
 #include "resource.h"
