@@ -475,10 +475,16 @@ void dep_cleanup()
 
 
 
+/*
+ * This routine is called on each cycle of the main loop.
+ */
+
 void
-end_proc()
+dep_main_loop_cycle()
 {
-	return;
+#if IBM_SP2==2
+    query_adp();
+#endif  /*IBM_SP2 */
 }
 
 /*
@@ -2412,7 +2418,6 @@ int get_la(
   }  /* END get_la() */
 
 
-
 #if IBM_SP2==1
 /*
  * dummy synbol for unknown IBM job manager routine,
