@@ -127,6 +127,10 @@
 #include	<ufs/ufs/quota.h>
 #include	<vm/vm_map.h>
 
+#ifdef USE_SYSCTL
+#include        <vm/vm_param.h>
+#endif
+
 #include	"portability.h"
 #include	"pbs_error.h"
 #include	"log.h"
@@ -761,7 +765,7 @@ int bs_cmp(
 int
 mom_get_sample()
 {
-	char			*id = "mom_get_sample";
+	char   *id = "mom_get_sample";
 	int			i;
 	struct	session		ss;
 	struct	kinfo_proc	*kp;
@@ -1639,6 +1643,12 @@ struct	rm_attribute	*attrib;
 	char		*id = "physmem";
 	struct	vmmeter	sum;
 	u_int		val;
+#ifdef USE_SYSCTL
+  int      mib[2];
+  size_t   len;
+  unsigned int      phys_mem;   
+  int      page_size;
+#endif
 
 	if (attrib) {
 		log_err(-1, id, extra_parm);
@@ -1646,6 +1656,7 @@ struct	rm_attribute	*attrib;
 		return NULL;
 	}
 
+#ifndef USE_SYSCTL
 	if (kd == NULL) {
 		log_err(-1, id, nokernel);
 		rm_errno = RM_ERR_SYSTEM;
@@ -1671,6 +1682,14 @@ struct	rm_attribute	*attrib;
 		val = sum.v_page_size / 1024;
 		val *= sum.v_page_count;
 	}
+#else
+  mib[0] = CTL_HW;        /* get physical memory */
+  mib[1] = HW_PHYSMEM;
+  len    = sizeof(phys_mem);
+  (void)sysctl(mib, 2, &phys_mem, &len, NULL,  0);
+
+  val = phys_mem / 1024;
+#endif
 	sprintf(ret_string, "%ukb", val);
 	return ret_string;
 }
@@ -1926,7 +1945,14 @@ get_la(rv)
 {
 	char	*id = "get_la";
 	long	la[3];
+#ifdef USE_SYSCTL
+  int      mib[2];
+  size_t   len;
+  unsigned int      phys_mem;
+  int      page_size;
+#endif
 
+#ifndef USE_SYSCTL
 	if (kd == NULL) {
 		log_err(-1, id, nokernel);
 		return (rm_errno = RM_ERR_SYSTEM);
@@ -1940,6 +1966,12 @@ get_la(rv)
 		log_err(errno, id, "kvm_read");
 		return (rm_errno = RM_ERR_SYSTEM);
 	}
+#else
+  mib[0] = CTL_VM;        /* get load average */
+  mib[1] = VM_LOADAVG;
+  len    = sizeof(la);
+  (void)sysctl(mib, 2, &la, &len, NULL,  0);
+#endif
 
 	*rv = (double)la[0]/(double)FSCALE;
 	return 0;
