@@ -137,7 +137,7 @@
 **		valid_user	is user name valid..
 */
 
-static char ident[] = "@(#) hpux10/$RCSfile$ $Revision: 991 $";
+static char ident[] = "@(#) hpux10/$RCSfile$ $Revision: 1894 $";
 
 #ifndef TRUE
 #define FALSE	0
@@ -208,12 +208,13 @@ struct	config	dependent_config[] = {
 };
 	
 /*
-**	Don't need any periodic processing.
-*/
+ * This routine is called on each cycle of the main loop.
+ */
+
 void
-end_proc()
+dep_main_loop_cycle()
 {
-	return;
+  /* Don't need any periodic processing. */
 }
 
 void
