@@ -135,7 +135,7 @@
 **		quota		quota information (sizes in KB)
 */
 
-static char ident[] = "@(#) sgi/$RCSfile$ $Revision: 991 $";
+static char ident[] = "@(#) sgi/$RCSfile$ $Revision: 1894 $";
 
 #ifndef TRUE
 #define FALSE	0
@@ -259,12 +259,13 @@ dep_cleanup()
 }
 
 /*
-**	Don't need any periodic procsessing.
-*/
+ * This routine is called on each cycle of the main loop.
+ */
+
 void
-end_proc()
+dep_main_loop_cycle()
 {
-	return;
+  /* No periodic functions. */
 }
 
 /*
