@@ -142,7 +142,7 @@
 #include	"resmon.h"
 #include	"../rm_dep.h"
 
-static char ident[] = "@(#) sun/$RCSfile$ $Revision: 991 $";
+static char ident[] = "@(#) sun/$RCSfile$ $Revision: 1894 $";
 
 #ifndef TRUE
 #define FALSE	0
@@ -241,10 +241,15 @@ dep_cleanup()
 	kd = NULL;
 }
 
+
+/*
+ * This routine is called on each cycle of the main loop.
+ */
+
 void
-end_proc()
+dep_main_loop_cycle()
 {
-	return;
+  /* No periodic functions. */
 }
 
 extern	struct	pbs_err_to_txt	pbs_err_to_txt[];
