@@ -135,7 +135,7 @@
 #include	"resmon.h"
 #include	"../rm_dep.h"
 
-static char ident[] = "@(#) c90/$RCSfile$ $Revision: 991 $";
+static char ident[] = "@(#) c90/$RCSfile$ $Revision: 1917 $";
 
 #ifndef max
 #define max(a,b) (a>b ? a : b)
@@ -362,10 +362,14 @@ struct	config	dependent_config[] = {
 	{ NULL,		{nullproc} },
 };
 
+/*
+ * This routine is called on each cycle of the main loop.
+ */
+
 void
-end_proc()
+dep_main_loop_cycle()
 {
-	char	*id = "end_proc";
+	char	*id = "dep_main_loop_cycle";
 	long	now, delta;
 	struct	tbs	info;
 	struct	pw	pw;
@@ -487,7 +491,6 @@ end_proc()
 	DBPRT(("%s: sios %d srate %.2f swap_rate %.2f\n",
 			id, newsios - oldsios, srate, swap_rate))
 	oldsios = newsios;
-	return;
 }
 
 void
@@ -517,9 +520,7 @@ dep_initialize()
 #if	SRFS
 	var_init();
 #endif
-	end_proc();
-
-	return;
+	dep_main_loop_cycle();
 }
 
 void
@@ -1556,7 +1557,7 @@ int mom_open_poll()
 #if	SRFS
 #define SETDEV(name, var) \
 	if ((dir = var_value(name)) != NULL) { \
-		i |= chk_file_sec(dir, 1, 1, S_IWGRP|S_IWOTH, 1); \
+		i |= chk_file_sec(dir, 1, 1, S_IWGRP|S_IWOTH, 1, NULL); \
 		if (quotactl(dir, SRFS_INFO, (caddr_t)&srfsinfo) == -1) \
 			log_err(errno, id, dir); \
 		else { \
@@ -1583,7 +1584,7 @@ int mom_open_poll()
 }
 #else
 #if !defined(DEBUG) && !defined(NO_SECURITY_CHECK)
-	if (chk_file_sec(TMP_DIR, 1, 1, S_IWGRP|S_IWOTH, 1)) return (PBSE_PERM);
+	if (chk_file_sec(TMP_DIR, 1, 1, S_IWGRP|S_IWOTH, 1, NULL)) return (PBSE_PERM);
 #endif	/* NO_SECURITY_CHECK */
 #endif	/* SRFS */
 	return (PBSE_NONE);
