@@ -102,7 +102,7 @@
 #include "mom_mach.h"
 #include "mom_func.h"
 
-static char ident[] = "@(#) $RCSfile$ $Revision: 983 $";
+static char ident[] = "@(#) $RCSfile$ $Revision: 1539 $";
 
 /* Global Variables */
 
@@ -649,24 +649,33 @@ struct sig_tbl sig_tbl[] = {
  * post_suspend - post exit of child for suspending a job
  */
 
-void post_suspend(pjob, err)
-	job *pjob;
-	int  err;
-{
+int post_suspend(
+
+  job *pjob,
+  int  err)
+
+  {
 	if (err == 0) {
 		pjob->ji_qs.ji_substate = JOB_SUBSTATE_SUSPEND;
 		pjob->ji_qs.ji_svrflags |= JOB_SVFLG_Suspend;
 	}
-}
+
+  return(0);
+  }
+
+
+
 
 /*
  * post_resume - post exit of child for suspending a job
  */
 
-void post_resume(pjob, err)
-	job *pjob;
-	int  err;
-{
+int post_resume(
+
+  job *pjob,
+  int  err)
+
+  {
 	if (err == 0) {
 		/*
 		 * adjust walltime for time suspended, ji_momstat contains
@@ -682,4 +691,9 @@ void post_resume(pjob, err)
 		pjob->ji_qs.ji_svrflags &= ~JOB_SVFLG_Suspend;
 
 	}
-}
+
+  return(0);
+  }
+
+
+
