@@ -76,7 +76,7 @@
 * This license will be governed by the laws of the Commonwealth of Virginia,
 * without reference to its choice of law rules.
 */
-/* $Id: dedicated.c 12 2005-02-22 20:59:54Z dev $ */
+/* $Id: dedicated.c 1861 2008-02-12 20:37:20Z garrick $ */
 
 /*
  *                 ***********************************
@@ -113,9 +113,9 @@
 #include <time.h>
 #include <errno.h>
 
-#include <pbs_error.h>
-#include <pbs_ifl.h>
-#include <log.h>
+#include "pbs_error.h"
+#include "pbs_ifl.h"
+#include "log.h"
 
 #ifdef	DBPRT
 #undef	DBPRT
