@@ -80,9 +80,9 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <pbs_error.h>
-#include <pbs_ifl.h>
-#include <log.h>
+#include "pbs_error.h"
+#include "pbs_ifl.h"
+#include "log.h"
 #include "queue_info.h"
 #include "constant.h"
 #include "misc.h"
