@@ -964,10 +964,11 @@ static int process_host_name_part(
           sizeof(struct in_addr),
           hp->h_addrtype)) == NULL) 
       {
-      sprintf(log_buffer,"cannot perform reverse name lookup for '%s' h_errno=%d errno=%d (check name server)",
+      sprintf(log_buffer,"cannot perform reverse name lookup for '%s' h_errno=%d errno=%d (%s) (check name server)",
         objname,
         h_errno, 
-        errno);
+        errno,
+        pbs_strerror(errno));
 
       free(phostname);
       phostname = NULL;
@@ -1042,10 +1043,11 @@ static int process_host_name_part(
 
       if ((hp = gethostbyname(hptr)) == NULL) 
         {
-        sprintf(log_buffer,"bad cname %s, h_errno=%d errno=%d",
+        sprintf(log_buffer,"bad cname %s, h_errno=%d errno=%d (%s)",
           hptr,
           h_errno,
-          errno);
+          errno,
+          pbs_strerror(errno));
 
         if (hname != NULL)
           {
@@ -1132,7 +1134,9 @@ static int process_host_name_part(
 int update_nodes_file()
 
   {
+#ifndef NDEBUG
   static char	id[] = "update_nodes_file";
+#endif
   struct pbsnode  *np;
   int	i, j;
   FILE	*nin;
@@ -1627,6 +1631,10 @@ int setup_nodes(void)
 
   svr_totnodes = 0;
 
+  /* clear out line so we don't have residual data if there is no LF */
+  
+  memset (line,'\0',sizeof(line));
+  
   for (linenum = 1;fgets(line,sizeof(line),nin);linenum++) 
     {
     if (line[0] == '#')	/* comment */
