@@ -118,6 +118,8 @@ char* array_disallowed_types[] = {
  *	value type
  */
 
+/* NOTE:  que_attr_def[] should be ordered with QA_ATR_* enum */
+
  /* for all queues */
 
 attribute_def que_attr_def[] = {
@@ -134,7 +136,7 @@ attribute_def que_attr_def[] = {
 	ATR_TYPE_STR,
 	PARENT_TYPE_QUE_ALL
     },
-/* QA_ATR_Priority */		/* priority of queue releative to others */
+/* QA_ATR_Priority */		/* priority of queue relative to others */
     {	ATTR_p,			/* "priority" */
 	decode_l,
 	encode_l,
@@ -146,6 +148,33 @@ attribute_def que_attr_def[] = {
 	ATR_TYPE_LONG,
 	PARENT_TYPE_QUE_ALL
     },
+
+/* QA_ATR_HostList */            /* HostList */
+    {   ATTR_hostlist,           /* "hostlist" */
+        decode_arst,
+        encode_arst,
+        set_hostacl,
+        comp_arst,
+        free_arst,
+        NULL_FUNC,
+        NO_USER_SET,
+        ATR_TYPE_ACL,
+        PARENT_TYPE_QUE_ALL
+    },
+
+/* QA_ATR_Rerunnable */    /* rerunnable */
+    {   ATTR_rerunnable,   /* "rerunnable" */
+        decode_b,
+        encode_b,
+        set_b,
+        comp_b,
+        free_null,
+        NULL_FUNC,
+        NO_USER_SET,
+        ATR_TYPE_LONG,
+        PARENT_TYPE_QUE_ALL
+    },
+
 /* QA_ATR_MaxJobs */		/* max number of jobs allowed in queue */
     {	ATTR_maxque,		/* "max_queuable" */
 	decode_l,
@@ -194,8 +223,8 @@ attribute_def que_attr_def[] = {
 	ATR_TYPE_STR,
 	PARENT_TYPE_QUE_ALL
     },
-/* QA_ATR_MaxRun */		/* max number of jobs allowed to run */
-    {	ATTR_maxrun,		/* "max_running" */
+/* QA_ATR_MaxReport */		/* max number of jobs reported for truncated output */
+    {	ATTR_maxreport,		/* "max_report" */
 	decode_l,
 	encode_l,
 	set_l,
@@ -206,6 +235,18 @@ attribute_def que_attr_def[] = {
 	ATR_TYPE_LONG,
 	PARENT_TYPE_QUE_ALL
     },
+/* QA_ATR_MaxRun */             /* max number of jobs allowed to run */
+    {   ATTR_maxrun,            /* "max_running" */
+        decode_l,
+        encode_l,
+        set_l,
+        comp_l,
+        free_null,
+        NULL_FUNC,
+        NO_USER_SET,
+        ATR_TYPE_LONG,
+        PARENT_TYPE_QUE_ALL
+    },
 /* QA_ATR_AclHostEnabled */	/* Host ACL to be used */
     {	ATTR_aclhten,		/* "acl_host_enable" */
 	decode_b,
@@ -376,10 +417,21 @@ attribute_def que_attr_def[] = {
         PARENT_TYPE_QUE_ALL
     },
 
-
    /* for execution queues only */
 
 
+/* QE_ATR_ChkptDir */
+    {   ATTR_chkptdir,   /* "checkpoint_dir" */
+    decode_str,
+    encode_str,
+    set_str,
+    comp_str,
+    free_str,
+    NULL_FUNC,
+    NO_USER_SET,
+    ATR_TYPE_STR,
+    PARENT_TYPE_QUE_EXC
+    },
 /* QE_ATR_ChkptMin */
     {	ATTR_chkptmin,		/* "checkpoint_min" */
 	decode_l,
