@@ -275,7 +275,18 @@ int reply_send(
     {
     /* Otherwise, the reply is to be sent to a remote client */
 
-    rc = dis_reply_write(sfds,&request->rq_reply);
+#ifndef PBS_MOM
+#ifdef AUTORUN_JOBS
+    if (request->rq_noreply != TRUE)
+      {
+#endif
+#endif
+      rc = dis_reply_write(sfds,&request->rq_reply);
+#ifndef PBS_MOM
+#ifdef AUTORUN_JOBS
+      }
+#endif
+#endif
     }
 
   free_br(request);
