@@ -84,6 +84,7 @@
 #include <pbs_config.h>   /* the master config generated by configure */
 
 #include <sys/types.h>
+#include <stdio.h>
 #include "libpbs.h"
 #include <errno.h>
 #include <signal.h>
@@ -105,10 +106,14 @@ static void post_signal_req A_((struct work_task *));
 
 /* Global Data Items: */
 
+extern int   LOGLEVEL;
 extern char *msg_momreject;
 
 extern void   set_old_nodes A_((job *));
 
+
+
+
 /*
  * req_signaljob - service the Signal Job Request
  *
@@ -117,13 +122,13 @@ extern void   set_old_nodes A_((job *));
 
 void req_signaljob(
 
-  struct batch_request *preq)
+  struct batch_request *preq)  /* I */
 
   {
   job *pjob;
   int  rc;
 
-  if ((pjob = chk_job_request(preq->rq_ind.rq_signal.rq_jid, preq)) == 0)
+  if ((pjob = chk_job_request(preq->rq_ind.rq_signal.rq_jid,preq)) == 0)
     {
     return;
     }
@@ -170,6 +175,18 @@ void req_signaljob(
     }
 #endif
 
+  if (LOGLEVEL >= 6)
+    {
+    sprintf(log_buffer,"relaying signal request to mom %lu",
+      pjob->ji_qs.ji_un.ji_exect.ji_momaddr);
+
+    log_record(
+      PBSEVENT_SCHED,
+      PBS_EVENTCLASS_REQUEST,
+      "req_signaljob",
+      log_buffer);
+    }
+
   /* pass the request on to MOM */
 
   if ((rc = relay_to_mom(
@@ -192,31 +209,47 @@ void req_signaljob(
 
 
 
+
 /*
  * issue_signal - send an internally generated signal to a running job
  */
 
-int issue_signal(pjob, signame, func, extra)
-	job  *pjob;
-	char *signame;	/* name of the signal to send */
-	void (*func) A_((struct work_task *));
-	void *extra;	/* extra parameter to be stored in sig request */
-{
-	struct batch_request *newreq;
+int issue_signal(
 
-	/* build up a Signal Job batch request */
+  job  *pjob,
+  char *signame,	/* name of the signal to send */
+  void (*func) A_((struct work_task *)),
+  void *extra)	/* extra parameter to be stored in sig request */
 
-	if ((newreq = alloc_br(PBS_BATCH_SignalJob))==(struct batch_request *)0)
-		return (PBSE_SYSTEM);
+  {
+  int rc;
 
-	newreq->rq_extra = extra;
-	(void)strcpy(newreq->rq_ind.rq_signal.rq_jid, pjob->ji_qs.ji_jobid);
-	(void)strncpy(newreq->rq_ind.rq_signal.rq_signame, signame, PBS_SIGNAMESZ);
-	return (relay_to_mom(pjob->ji_qs.ji_un.ji_exect.ji_momaddr,
-			      newreq, func)); 
+  struct batch_request *newreq;
 
-	/* when MOM replies, we just free the request structure */
-}
+  /* build up a Signal Job batch request */
+
+  if ((newreq = alloc_br(PBS_BATCH_SignalJob)) == NULL)
+    {
+    /* FAILURE */
+
+    return(PBSE_SYSTEM);
+    }
+
+  newreq->rq_extra = extra;
+
+  strcpy(newreq->rq_ind.rq_signal.rq_jid,pjob->ji_qs.ji_jobid);
+
+  strncpy(newreq->rq_ind.rq_signal.rq_signame,signame,PBS_SIGNAMESZ);
+
+  rc = relay_to_mom(
+    pjob->ji_qs.ji_un.ji_exect.ji_momaddr,
+    newreq,
+    func); 
+
+  /* when MOM replies, we just free the request structure */
+
+  return(rc);
+  }  /* END issue_signal() */
 
 
 
