@@ -119,7 +119,7 @@ extern attribute_def  node_attr_def[];   /* node attributes defs */
 extern int	       pbs_mom_port;
 extern time_t	       time_now;
 extern char	      *msg_init_norerun;
-extern struct pbsnode *tfind_addr();
+extern struct pbsnode *tfind_addr(const u_long);
 extern int             LOGLEVEL;
 
 /* Extern Functions */
