@@ -463,7 +463,7 @@ resource_def svr_resc_def_const[] = {
 	comp_l,
 	free_null,
 	NULL_FUNC,
-	READ_WRITE | ATR_DFLAG_MOM,
+	READ_WRITE | ATR_DFLAG_MOM | ATR_DFLAG_RMOMIG,
 	ATR_TYPE_LONG
     },
     {	"mppe",				/* number of mpp nodes */
@@ -503,7 +503,7 @@ resource_def svr_resc_def_const[] = {
         comp_size,
         free_null,
 	NULL_FUNC,
-        READ_WRITE | ATR_DFLAG_MOM | ATR_DFLAG_ALTRUN,
+	READ_WRITE | ATR_DFLAG_MOM | ATR_DFLAG_ALTRUN,
         ATR_TYPE_SIZE
     },
     {	"srfs_tmp",			/* SRFS TMPDIR allocation */
@@ -624,7 +624,7 @@ resource_def svr_resc_def_const[] = {
         READ_WRITE,
         ATR_TYPE_STR
     },
-    {   "mpptimeMPP",   /* NYI */
+    {   "mpptime",   /* NYI */
         decode_time,
         encode_time,
         set_l,
@@ -634,7 +634,7 @@ resource_def svr_resc_def_const[] = {
         READ_WRITE,
         ATR_TYPE_LONG
     },
-    {   "mpphostMPP",
+    {   "mpphost",
         decode_str,
         encode_str,
         set_str,
@@ -644,7 +644,7 @@ resource_def svr_resc_def_const[] = {
         READ_WRITE,
         ATR_TYPE_STR
     },
-    {   "mpparchMPP",    /* node architecture (XT3, XT4, etc.) */
+    {   "mpparch",    /* node architecture (XT3, XT4, etc.) */
         decode_str,
         encode_str,
         set_str,
