@@ -89,6 +89,7 @@
  *	job_set_wait()	   - set event for when job's wait time ends
  *	get_variable()	   - get value of a single environ variable of a job 
  *	prefix_std_file()  - build the fully prefixed default name for std e/o
+ *	add_std_filename()  - add the default name for std e/o
  *	get_jobowner()	   - get job owner name without @host suffix
  *	set_resc_deflt()   - set unspecified resource_limit to default values
  *	set_statechar()	   - set the job state attribute character value
@@ -1097,6 +1098,10 @@ int svr_chkque(
 
     if (site_acl_check(pjob,pque))
       {
+      if (EMsg) snprintf(EMsg,1024,
+        "site_acl_check() failed: user %s, queue %s",
+        pjob->ji_wattr[(int)JOB_ATR_job_owner].at_val.at_str,
+        pque->qu_qs.qu_name);
       return(PBSE_PERM);
       }
 
@@ -1106,6 +1111,8 @@ int svr_chkque(
          &pjob->ji_wattr[(int)JOB_ATR_resource],
          &svr_resc_def[svr_resc_size - 1]) != 0)
       {
+      if (EMsg) snprintf(EMsg,1024,
+        "detected request for an unknown resource");
       return(PBSE_UNKRESC);
       }
 
@@ -1113,6 +1120,8 @@ int svr_chkque(
 
     if (pjob->ji_wattr[(int)JOB_ATR_UNKN].at_flags & ATR_VFLAG_SET)
       {
+      if (EMsg) snprintf(EMsg,1024,
+        "detected presence of an unknown attribute");
       return(PBSE_NOATTR);
       }
 
@@ -1132,6 +1141,10 @@ int svr_chkque(
           if (strcmp(Q_DT_interactive, 
                 pque->qu_attr[QA_ATR_DisallowedTypes].at_val.at_arst->as_string[i]) == 0)
             {
+            if (EMsg) snprintf(EMsg,1024,
+              "interactive job is not allowed for queue: user %s, queue %s",
+              pjob->ji_wattr[(int)JOB_ATR_job_owner].at_val.at_str,
+              pque->qu_qs.qu_name);
             return(PBSE_NOINTERACTIVE);
             }
           }
@@ -1140,6 +1153,10 @@ int svr_chkque(
           if (strcmp(Q_DT_batch, 
                pque->qu_attr[QA_ATR_DisallowedTypes].at_val.at_arst->as_string[i]) == 0)
             {
+            if (EMsg) snprintf(EMsg,1024,
+              "batch job is not allowed for queue: user %s, queue %s",
+              pjob->ji_wattr[(int)JOB_ATR_job_owner].at_val.at_str,
+              pque->qu_qs.qu_name);
             return(PBSE_NOBATCH);
             }
           }
@@ -1149,6 +1166,10 @@ int svr_chkque(
             && (pjob->ji_wattr[(int)JOB_ATR_rerunable].at_flags & ATR_VFLAG_SET &&
 	        pjob->ji_wattr[(int)JOB_ATR_rerunable].at_val.at_long > 0))
 	  {
+          if (EMsg) snprintf(EMsg,1024,
+            "rerunable job is not allowed for queue: user %s, queue %s",
+            pjob->ji_wattr[(int)JOB_ATR_job_owner].at_val.at_str,
+            pque->qu_qs.qu_name);
 	  return(PBSE_NORERUNABLE);
 	  }
 
@@ -1157,6 +1178,10 @@ int svr_chkque(
             && (!(pjob->ji_wattr[(int)JOB_ATR_rerunable].at_flags & ATR_VFLAG_SET) ||
 	        pjob->ji_wattr[(int)JOB_ATR_rerunable].at_val.at_long == 0))
 	  {
+          if (EMsg) snprintf(EMsg,1024,
+            "only rerunable jobs are allowed for queue: user %s, queue %s",
+            pjob->ji_wattr[(int)JOB_ATR_job_owner].at_val.at_str,
+            pque->qu_qs.qu_name);
 	  return(PBSE_NONONRERUNABLE);
 	  }
         }	
@@ -1245,6 +1270,10 @@ int svr_chkque(
           else
             {
             /* no user acl, fail immediately */
+            if (EMsg) snprintf(EMsg,1024,
+              "group ACL is not satisfied: user %s, queue %s",
+              pjob->ji_wattr[(int)JOB_ATR_job_owner].at_val.at_str,
+              pque->qu_qs.qu_name);
 
             return(PBSE_PERM);
             }
@@ -1261,12 +1290,21 @@ int svr_chkque(
 
     if (pque->qu_attr[QA_ATR_Enabled].at_val.at_long == 0)
       {
+      if (EMsg) snprintf(EMsg,1024,
+        "queue is disabled: user %s, queue %s",
+        pjob->ji_wattr[(int)JOB_ATR_job_owner].at_val.at_str,
+        pque->qu_qs.qu_name);
       return(PBSE_QUNOENB);
       }
 
     if ((pque->qu_attr[QA_ATR_MaxJobs].at_flags & ATR_VFLAG_SET) &&
         ((pque->qu_numjobs - pque->qu_numcompleted) >= pque->qu_attr[QA_ATR_MaxJobs].at_val.at_long))
       {
+      if (EMsg) snprintf(EMsg,1024,
+        "total number of jobs in queue exceeds the queue limit: "
+        "user %s, queue %s",
+        pjob->ji_wattr[(int)JOB_ATR_job_owner].at_val.at_str,
+        pque->qu_qs.qu_name);
       return(PBSE_MAXQUED);
       }
 
@@ -1289,6 +1327,11 @@ int svr_chkque(
 
       if (user_jobs >= pque->qu_attr[QA_ATR_MaxUserJobs].at_val.at_long)
         {
+        if (EMsg) snprintf(EMsg,1024,
+          "total number of current user's jobs exceeds the queue limit: "
+          "user %s, queue %s",
+          pjob->ji_wattr[(int)JOB_ATR_job_owner].at_val.at_str,
+          pque->qu_qs.qu_name);
         return(PBSE_MAXUSERQUED);
         }
       }
@@ -1300,6 +1343,11 @@ int svr_chkque(
       {
       if (mtype == MOVE_TYPE_Move)  /* ok if not plain user */
         {
+        if (EMsg) snprintf(EMsg,1024,
+          "queue accepts only routed jobs, no direct submission: "
+          "user %s, queue %s",
+          pjob->ji_wattr[(int)JOB_ATR_job_owner].at_val.at_str,
+          pque->qu_qs.qu_name);
         return(PBSE_QACESS);
         }
       }
@@ -1315,6 +1363,11 @@ int svr_chkque(
       {
       if (acl_check(&pque->qu_attr[QA_ATR_AclHost],hostname,ACL_Host) == 0)
         {
+        if (EMsg) snprintf(EMsg,1024,
+          "host ACL rejected the submitting host: "
+          "user %s, queue %s, host %s",
+          pjob->ji_wattr[(int)JOB_ATR_job_owner].at_val.at_str,
+          pque->qu_qs.qu_name, hostname);
         return(PBSE_BADHOST);
         }
       }
@@ -1343,6 +1396,11 @@ int svr_chkque(
         else
           {
           /* no group acl, fail immediately */
+          if (EMsg) snprintf(EMsg,1024,
+            "user ACL rejected the submitting user: "
+            "user %s, queue %s",
+            pjob->ji_wattr[(int)JOB_ATR_job_owner].at_val.at_str,
+            pque->qu_qs.qu_name);
 
           return(PBSE_PERM);
           }
@@ -1353,6 +1411,11 @@ int svr_chkque(
 
     if (failed_group_acl && failed_user_acl)
       {
+      if (EMsg) snprintf(EMsg,1024,
+        "both user and group ACL rejected the submitting user: "
+        "user %s, queue %s",
+        pjob->ji_wattr[(int)JOB_ATR_job_owner].at_val.at_str,
+        pque->qu_qs.qu_name);
       return(PBSE_PERM);
       }
 
@@ -1606,6 +1669,42 @@ char *prefix_std_file(
   }
 
 
+/*
+ * add_std_filename - add the default file name for the job's
+ *	standard output or error: 
+ *		job_name.[e|o]job_sequence_number
+ */
+
+char *add_std_filename(
+
+  job *pjob,
+  char * path,
+  int  key)
+
+  {
+  int	 len;
+  char	*name = (char *)0;
+
+  len = strlen(path) +
+        strlen(pjob->ji_wattr[(int)JOB_ATR_jobname].at_val.at_str) + 
+        PBS_MAXSEQNUM + 
+        5;
+
+  name = malloc(len);
+    
+  if (name) 
+    {
+    strcpy(name,path);
+    strcat(name,"/");	/* the final /		*/
+
+					/* now add the rest	*/
+    default_std(pjob,key,name + strlen(name));
+    }
+
+  return(name);
+  }
+
+
 
 
 /*
@@ -1726,12 +1825,14 @@ void set_resc_deflt(
 
   /* apply queue max limits first since they take precedence */
 
+#ifndef RESOURCEMAXNOTDEFAULT
   set_deflt_resc(ja,&pque->qu_attr[(int)QA_ATR_ResourceMax]);
 
   /* server max limits will only be applied to attributes which have
      not yet been set */
 
   set_deflt_resc(ja,&server.sv_attr[(int)SRV_ATR_ResourceMax]);
+#endif
 
   for (i = 0;i < JOB_ATR_LAST;++i)
     {
