@@ -653,6 +653,18 @@ int send_job(
     if (sigprocmask(SIG_UNBLOCK,&child_set,NULL) == -1)
       log_err(errno,id,spfail);
 
+    if (LOGLEVEL >= 7)
+      {
+      sprintf(log_buffer,"send_job child job pid is %d",
+        pid);
+
+      log_event(
+        PBSEVENT_JOB,
+        PBS_EVENTCLASS_JOB,
+        jobp->ji_qs.ji_jobid,
+        log_buffer);
+      }
+
     if (LOGLEVEL >= 1)
       {
       extern long   DispatchTime[];
